@@ -16,7 +16,7 @@ from rich.table import Table
 from rich import print
 
 # MyFunctions
-from jh_matrix import matrixrain
+import justhacking.jh_matrix  
 
 
 # configuration
@@ -38,7 +38,7 @@ def banner():
 #===========================================================
 def mr():
   try:
-    matrixrain()
+    justhacking.jh_matrix.matrixrain()
   except KeyboardInterrupt:
     exit()
 
